<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<xsl:stylesheet xmlns="http://www.gekid.de/namespace" xmlns:aqua="http://www.aqua-institut.de" 
	xmlns:saxon="http://saxon.sf.net" xmlns:xalan="http://xml.apache.org/xalan" 
	xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="xs xsi aqua saxon xalan #default" 
	version="2.0" xpath-default-namespace="urn:gba:sqg">
	<xsl:output encoding="UTF-8" indent="yes" method="xml"/>
	
	<xsl:output omit-xml-declaration="yes" indent="yes"/>
	<xsl:strip-space elements="*"/>
	
	<xsl:template match="/">
		<xsl:variable name="schema_version" select="/root/header/document/software/specification/@Schema_Version"/>
		<ADT_GEKID Schema_Version="{$schema_version}">
			<xsl:variable name="root" select="/"/>
			<xsl:apply-templates mode="absender" 
			    select="(//felder[Absender_ID/@V])[1]"/>

		<Menge_Patient>
			<xsl:variable name="patient_ids" select="distinct-values(//felder/Patient_ID/@V)"/>
			<xsl:for-each select="$patient_ids">
				<xsl:variable name="patient_id" select="."/>
				<Patient>
					<Patienten_Stammdaten Patient_ID="{$patient_id}">
						<!-- .// nur im aktuellen Node sonst werden alle case-Elemente ausgewählt -->
						<xsl:apply-templates select="($root//case[.//felder[Patient_ID/@V = $patient_id]])[1]" mode="patient_stammdaten"/>
					</Patienten_Stammdaten>
					<Menge_Meldung>
						<xsl:variable name="meldung_ids" select="distinct-values($root//felder[Patient_ID/@V = $patient_id]/Meldung_ID/@V)"/>
						<xsl:for-each select="$meldung_ids">
							<xsl:variable name="meldung_id" select="."/>
							<xsl:call-template name="meldung">
								<xsl:with-param name="cases" select="$root//case[qs_data/*/felder[Meldung_ID/@V = $meldung_id]]"/>
							</xsl:call-template>
						</xsl:for-each>
					</Menge_Meldung>
				</Patient>
			</xsl:for-each>
		</Menge_Patient>
		
		<Menge_Melder>
			<xsl:variable name="melder_ids" select="distinct-values($root//felder/Melder_ID/@V)"/>
			<xsl:for-each select="$melder_ids">
				<!-- select des Werts aus select-statement -->
				<xsl:variable name="melder_id" select="."/>
				<!-- call a template with name melder-->
				<xsl:call-template name="melder">
					<!-- übrtgabe von Parameter an das aufgerufende Template -->
					<xsl:with-param name="cases" select="$root//case[qs_data/*/felder[Melder_ID/@V = $melder_id]]"/>
				</xsl:call-template>
			</xsl:for-each>
		</Menge_Melder>
		</ADT_GEKID>
	</xsl:template>

	<xsl:template name="melder">
		<!--übernahme der Paramter-Results-->
		<xsl:param name="cases"/>
		<!-- nicht alle cases von derselben ID werden benötigt -->
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<Melder Melder_ID="{$ref_fields/Melder_ID/@V}">
			<!-- own function -->
			<xsl:copy-of select="aqua:fields($ref_fields, ('Melder_IKNR', 'Melder_LANR', 'Melder_BSNR', 'Meldende_Stelle', 'Melder_KH_Abt_Station_Praxis', 'Melder_Arztname', 'Melder_Anschrift', 'Melder_PLZ', 'Melder_Ort', 'Melder_Bankname', 'Melder_Kontoinhaber', 'Melder_BIC', 'Melder_IBAN'))"/>
		</Melder>
	</xsl:template>


	<xsl:template name="meldung">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<xsl:variable name="meldung_id" select="$ref_fields[1]/Meldung_ID/@V"/>
		<xsl:variable name="melder_id" select="$ref_fields[1]/Melder_ID/@V"/>
		<Meldung Meldung_ID="{$meldung_id}" Melder_ID="{$melder_id}">
			
			<xsl:apply-templates mode="value" select="$ref_fields/Meldedatum"/>
			<xsl:apply-templates mode="value" select="$ref_fields/Meldebegruendung"/>
			<xsl:apply-templates mode="value" select="$ref_fields/Meldeanlass"/>
			
			<Tumorzuordnung Tumor_ID="{$ref_fields/Tumor_ID/@V}">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Primaertumor_ICD_Code','Primaertumor_ICD_Version'))"/>
			
				<xsl:variable name="diagnosedatum_krd"  select="aqua:fields($ref_fields, ('Diagnosedatum_XXX_KRD_PRIMTUM'))"/>
				<xsl:variable name="diagnosedatum_kro"  select="aqua:fields($ref_fields, ('Diagnosedatum_XXX_KRO_PRIMTUM'))"/>
				<xsl:variable name="diagnosedatum_krst" select="aqua:fields($ref_fields, ('Diagnosedatum_XXX_KRST_PRIMTUM'))"/>
				<xsl:variable name="diagnosedatum_krsy" select="aqua:fields($ref_fields, ('Diagnosedatum_XXX_KRSY_PRIMTUM'))"/>
				<xsl:variable name="diagnosedatum_krv"  select="aqua:fields($ref_fields, ('Diagnosedatum_XXX_KRV_PRIMTUM'))"/>
				
				<xsl:choose>
					<xsl:when test="$diagnosedatum_krd">
						<xsl:copy-of select="$diagnosedatum_krd"/>
					</xsl:when>
					<xsl:when test="$diagnosedatum_kro">
						<xsl:copy-of select="$diagnosedatum_kro"/>
					</xsl:when>
					<xsl:when test="$diagnosedatum_krst">
						<xsl:copy-of select="$diagnosedatum_krst"/>
					</xsl:when>
					<xsl:when test="$diagnosedatum_krsy">
						<xsl:copy-of select="$diagnosedatum_krsy"/>
					</xsl:when>
					<xsl:when test="$diagnosedatum_krv">
						<xsl:copy-of select="$diagnosedatum_krv"/>
					</xsl:when>
				</xsl:choose>
				
				<xsl:copy-of select="aqua:fields($ref_fields, ('Seitenlokalisation'))"/>
			</Tumorzuordnung>

			<xsl:variable name="diagnose_cases" select="$cases[.//qs_data/@module = 'KRD']"/>
			<xsl:if test="count($diagnose_cases) &gt; 0">
				<xsl:call-template name="diagnose">
					<xsl:with-param name="cases" select="$cases[.//qs_data/@module = 'KRD']"/>
				</xsl:call-template>
			</xsl:if>
			
			
			<xsl:variable name="op_cases" select="$cases[.//qs_data/@module = 'KRO']"/>
			
						
			<xsl:variable name="menge_op">
			<xsl:call-template name="op">
				<xsl:with-param name="cases" select="$op_cases"/>
			</xsl:call-template>
			</xsl:variable>
			<xsl:if test="$menge_op/*">
				<Menge_OP>
					<xsl:copy-of select="$menge_op"/>
				</Menge_OP>
			</xsl:if>
			
			
			<xsl:variable name="st_cases" select="$cases[.//qs_data/@module = 'KRST']"/>
			<xsl:variable name="menge_st">
				<xsl:call-template name="st">
					<xsl:with-param name="cases" select="$st_cases"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:if test="$menge_st/*">
				<Menge_ST>
					<xsl:copy-of select="$menge_st"/>
				</Menge_ST>
			</xsl:if>
			

			<xsl:variable name="syst_cases" select="$cases[.//qs_data/@module = 'KRSY']"/>
			<xsl:variable name="menge_syst">
			<xsl:call-template name="syst">
				<xsl:with-param name="cases" select="$syst_cases"/>
			</xsl:call-template>
			</xsl:variable>
			<xsl:if test="$menge_syst/*">
				<Menge_SYST>
					<xsl:copy-of select="$menge_syst"/>
				</Menge_SYST>
			</xsl:if>
			
			<xsl:variable name="verlauf_cases" select="$cases[.//qs_data/@module = 'KRV']"/>
			<xsl:variable name="menge_verlauf">
				<xsl:call-template name="verlauf">
					<xsl:with-param name="cases" select="$verlauf_cases"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:if test="$menge_verlauf/*">
				<Menge_Verlauf>
					<xsl:copy-of select="$menge_verlauf"/>
				</Menge_Verlauf>
			</xsl:if>			
			
			
			<xsl:variable name="menge_tumorkonferenz">
				<xsl:call-template name="tumorkonferenz">
					<xsl:with-param name="cases" select="($diagnose_cases | $verlauf_cases)"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:if test="$menge_tumorkonferenz/*">
				<Menge_Tumorkonferenz>
					<xsl:copy-of select="$menge_tumorkonferenz"/>
				</Menge_Tumorkonferenz>
			</xsl:if>
			
			<xsl:if test="count($verlauf_cases) &gt; 0">
				<xsl:variable name="menge_zusatzitem">
					<xsl:call-template name="zusatzitem">
						<xsl:with-param name="cases" select="$verlauf_cases"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="$menge_zusatzitem/*">
					<Menge_Zusatzitem>
						<xsl:copy-of select="$menge_zusatzitem"/>
					</Menge_Zusatzitem>
				</xsl:if>
			</xsl:if>
		</Meldung>
	</xsl:template>


	<xsl:template name="diagnose">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<Diagnose Tumor_ID="{$ref_fields/Tumor_ID/@V}">
			<xsl:copy-of select="aqua:fields($ref_fields, ('Primaertumor_ICD_Code', 'Primaertumor_ICD_Version', 'Primaertumor_Diagnosetext', 'Primaertumor_Topographie_ICD_O', 'Primaertumor_Topographie_ICD_O_Version', 'Primaertumor_Topographie_ICD_O_Freitext', 'Diagnosedatum_XXX_KRD_PRIMTUM '))"/>

			<xsl:choose>
				<xsl:when test="$ref_fields/Diagnosesicherung[@V = '7']">
					<Diagnosesicherung>7</Diagnosesicherung>
				</xsl:when>
				<xsl:when test="$ref_fields/Diagnosesicherung[@V = '6']">
					<Diagnosesicherung>6</Diagnosesicherung>
				</xsl:when>
				<xsl:when test="$ref_fields/Diagnosesicherung[@V = '5']">
					<Diagnosesicherung>5</Diagnosesicherung>
				</xsl:when>
				<xsl:when test="$ref_fields/Diagnosesicherung[@V = '4']">
					<Diagnosesicherung>4</Diagnosesicherung>
				</xsl:when>
				<xsl:when test="$ref_fields/Diagnosesicherung[@V = '2']">
					<Diagnosesicherung>2</Diagnosesicherung>
				</xsl:when>
				<xsl:when test="$ref_fields/Diagnosesicherung[@V = '1']">
					<Diagnosesicherung>1</Diagnosesicherung>
				</xsl:when>
				<xsl:when test="$ref_fields/Diagnosesicherung[@V = '9']">
					<Diagnosesicherung>9</Diagnosesicherung>
				</xsl:when>
			</xsl:choose>

			<xsl:copy-of select="aqua:fields($ref_fields, ('Seitenlokalisation', 'Fruehere_Tumorerkrankungen'))"/>


			<xsl:variable name="menge_fruehtumor">
				<xsl:apply-templates select="$cases//felder[1]" mode="fruehtumor"/>
			</xsl:variable>
			<xsl:if test="$menge_fruehtumor/*">
				<Menge_Fruehere_Tumorerkrankung>
					<xsl:copy-of select="$menge_fruehtumor"/>		
				</Menge_Fruehere_Tumorerkrankung>
			</xsl:if>			

			<xsl:variable name="menge_hist">
				<xsl:apply-templates select="$cases//felder[1]" mode="histologie"/>
			</xsl:variable>
			<xsl:if test="$menge_hist/*">
				<Menge_Histologie>
					<xsl:copy-of select="$menge_hist"/>
				</Menge_Histologie>
			</xsl:if>

			<xsl:variable name="menge_fm">
				<xsl:apply-templates select="($cases//felder)[1]" mode="fm"/>
			</xsl:variable>
			<xsl:if test="$menge_fm/*">
				<Menge_FM>
					<xsl:copy-of select="$menge_fm"/>
				</Menge_FM>
			</xsl:if>

			<xsl:variable name="ctnm">
				<xsl:apply-templates select="$cases//felder[1]/Menge_TNM/TNM[1]" mode="tnmd"/>
			</xsl:variable>
			
			<xsl:variable name="ptnm">
				<xsl:apply-templates select="$cases//felder[1]/Menge_TNM/TNM[2]" mode="tnmd"/>
			</xsl:variable>
		
			<xsl:variable name="tnm_ext">
				<xsl:apply-templates select="$cases//felder[1]" mode="tnme"/>
			</xsl:variable>
				
			<xsl:if test="$ctnm/* and $ptnm/*">
				<cTNM>
					<xsl:copy-of select="$ctnm"/>
					<xsl:if test="$tnm_ext/* and not($ptnm/*)">
						<xsl:copy-of select="$tnm_ext"/>
					</xsl:if>	
				</cTNM>
				<pTNM>
					<xsl:copy-of select="$ptnm"/>
					<xsl:if test="$tnm_ext/*">
						<xsl:copy-of select="$tnm_ext"/>
					</xsl:if>	
				</pTNM>
			</xsl:if>

			<xsl:if test="$ctnm/* and not($ptnm/*)">
				<xsl:variable name="pefix_t" as="text()">	
					<xsl:value-of select="$ctnm/*[starts-with(name(), 'TNM_c_p_u_Praefix_T')]"/>		
				</xsl:variable>	
				<xsl:variable name="pefix_n" as="text()">	
					<xsl:value-of select="$ctnm/*[starts-with(name(), 'TNM_c_p_u_Praefix_N')]"/>		
				</xsl:variable>	
				<xsl:variable name="pefix_m" as="text()">	
					<xsl:value-of select="$ctnm/*[starts-with(name(), 'TNM_c_p_u_Praefix_M')]"/>		
				</xsl:variable>
				
				<xsl:variable name="pPrefix" select="$pefix_t = 'p' or $pefix_n = 'p' or $pefix_m ='p'"/>
				
				<xsl:choose>
					<xsl:when test="$pPrefix">
						<pTNM>
							<xsl:copy-of select="$ctnm"/>
							<xsl:if test="$tnm_ext/*">
								<xsl:copy-of select="$tnm_ext"/>
							</xsl:if>	
						</pTNM>
					</xsl:when>		
					<xsl:otherwise >
						<cTNM>
							<xsl:copy-of select="$ctnm"/>
							<xsl:if test="$tnm_ext/*">
								<xsl:copy-of select="$tnm_ext"/>
							</xsl:if>	
						</cTNM>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			
			<xsl:variable name="menge_wk">
				<xsl:apply-templates select="$cases//felder[1]" mode="wk"/>
			</xsl:variable>
			<xsl:if test="$menge_wk/*">
				<Menge_Weitere_Klassifikation>
					<xsl:copy-of select="$menge_wk"/>
				</Menge_Weitere_Klassifikation>
			</xsl:if>

			<!-- Mamma -->
			<xsl:variable name="modul_mamma">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('Praetherapeutischer_Menopausenstatus','HormonrezeptorStatus_Oestrogen','HormonrezeptorStatus_Progesteron','Her2neuStatus','PraeopDrahtmarkierung','IntraopPraeparatkontroll','TumorgroesseInvasiv','TumorgroesseDCIS'))"/>
			</xsl:variable>
			<xsl:if test="$modul_mamma/*">
				<Modul_Mamma>
					<xsl:copy-of select="$modul_mamma"/>
				</Modul_Mamma>
			</xsl:if>
			
			<!-- Darm -->
			<xsl:variable name="modul_darm">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('RektumAbstandAnokutanlinie','RektumAbstandAboralerResektionsrand','RektumAbstandCircResektionsebene','RektumQualitaetTME','RektumMRTDuennschichtAngabemesorektaleFaszie','ArtEingriff','RektumAnzeichnungStomaposition','GradRektumAnastomoseninsuffizienz','ASA','RASMutation'))"/>
			</xsl:variable>
			<xsl:if test="$modul_darm/*">
				<Modul_Darm>
					<xsl:copy-of select="$modul_darm"/>
				</Modul_Darm>
			</xsl:if>
			<!-- Modul_Allgemein -->
			<xsl:variable name="modul_allgemein_dienstkontakt">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumSozialdienstkontakt'))"/>
			</xsl:variable>
			
			<xsl:variable name="modul_allgemein_rekrutierung">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumStudienrekrutierung'))"/>
			</xsl:variable>
			<xsl:if test="$modul_allgemein_dienstkontakt/* or $modul_allgemein_rekrutierung/*">
				<Modul_Allgemein>
					<xsl:if test="$modul_allgemein_dienstkontakt/*">
						<xsl:copy-of select="$modul_allgemein_dienstkontakt"/>
					</xsl:if>	
					<xsl:if test="$modul_allgemein_rekrutierung/*">
						<xsl:copy-of select="$modul_allgemein_rekrutierung"/>
					</xsl:if>
				</Modul_Allgemein>
			</xsl:if>
			<!-- Ende Modul -->
			<xsl:copy-of select="aqua:fields($ref_fields, ('Allgemeiner_Leistungszustand', 'Anmerkung'))"/>
		</Diagnose>
	</xsl:template>


	<xsl:template name="op">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<xsl:variable name="op">
			<xsl:copy-of select="aqua:fields($ref_fields, ('OP_Intention', 'OP_Datum'))"/>
			<xsl:variable name="menge_ops">
				<xsl:copy-of select="aqua:fields($ref_fields, ('OP_OPS'))"/>
			</xsl:variable>
			<xsl:if test="$menge_ops/*">
				<Menge_OPS>
					<xsl:copy-of select="$menge_ops"/>
				</Menge_OPS>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('OP_OPS_Version'))"/>
			
			<xsl:apply-templates select="$cases[1]//felder" mode="histologie"/>

			<xsl:variable name="menge_tnm">
				<xsl:apply-templates select="$cases//felder[1]" mode="tnm"/>
			</xsl:variable>
			<xsl:if test="$menge_tnm/*">
				
					<xsl:copy-of select="$menge_tnm"/>
				
			</xsl:if>
			<xsl:variable name="residualstatus">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Lokale_Beurteilung_Residualstatus', 'Gesamtbeurteilung_Residualstatus'))"/>
			</xsl:variable>
			<xsl:if test="$residualstatus/*">
				<Residualstatus>
					<xsl:copy-of select="$residualstatus"/>
				</Residualstatus>
			</xsl:if>
			<xsl:variable name="menge_komp">
				<xsl:copy-of select="aqua:fields($ref_fields, ('OP_Komplikation'))"/>
				<xsl:for-each select="$ref_fields/OP_Komplikationen/@V">
					<OP_Komplikation><xsl:value-of select="."/></OP_Komplikation>
				</xsl:for-each>
			</xsl:variable>
			<xsl:if test="$menge_komp/*">
				<Menge_Komplikation>
					<xsl:copy-of select="$menge_komp"/>
				</Menge_Komplikation>
			</xsl:if>

			<!-- Mamma -->
			<xsl:variable name="modul_mamma">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('Praetherapeutischer_Menopausenstatus','HormonrezeptorStatus_Oestrogen','HormonrezeptorStatus_Progesteron','Her2neuStatus','PraeopDrahtmarkierung','IntraopPraeparatkontroll','TumorgroesseInvasiv','TumorgroesseDCIS'))"/>
			</xsl:variable>
			<xsl:if test="$modul_mamma/*">
				<Modul_Mamma>
					<xsl:copy-of select="$modul_mamma"/>
				</Modul_Mamma>
			</xsl:if>
			
			<!-- Darm -->
			<xsl:variable name="modul_darm">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('RektumAbstandAnokutanlinie','RektumAbstandAboralerResektionsrand','RektumAbstandCircResektionsebene','RektumQualitaetTME','RektumMRTDuennschichtAngabemesorektaleFaszie','ArtEingriff','RektumAnzeichnungStomaposition','GradRektumAnastomoseninsuffizienz','ASA','RASMutation'))"/>
			</xsl:variable>
			<xsl:if test="$modul_darm/*">
				<Modul_Darm>
					<xsl:copy-of select="$modul_darm"/>
				</Modul_Darm>
			</xsl:if>
			<!-- Modul_Allgemein -->
			<xsl:variable name="modul_allgemein_dienstkontakt">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumSozialdienstkontakt'))"/>
			</xsl:variable>
			
			<xsl:variable name="modul_allgemein_rekrutierung">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumStudienrekrutierung'))"/>
			</xsl:variable>
			<xsl:if test="$modul_allgemein_dienstkontakt/* or $modul_allgemein_rekrutierung/*">
				<Modul_Allgemein>
					<xsl:if test="$modul_allgemein_dienstkontakt/*">
						<xsl:copy-of select="$modul_allgemein_dienstkontakt"/>
					</xsl:if>	
					<xsl:if test="$modul_allgemein_rekrutierung/*">
						<xsl:copy-of select="$modul_allgemein_rekrutierung"/>
					</xsl:if>
				</Modul_Allgemein>
			</xsl:if>
			<!-- Ende Modul -->

			<xsl:variable name="menge_operateur">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Name_Operateur'))"/>
			</xsl:variable>
			<xsl:if test="$menge_operateur/*">
				<Menge_Operateur>
					<xsl:copy-of select="$menge_operateur"/>
				</Menge_Operateur>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Anmerkung'))"/>
		</xsl:variable>
		<xsl:if test="$op/*">
			<OP OP_ID="{$ref_fields/OP_ID/@V}">
				<xsl:copy-of select="$op"/>
			</OP>
		</xsl:if>
	</xsl:template>


	<xsl:template name="st">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<xsl:variable name="st">
			<xsl:copy-of select="aqua:fields($ref_fields, ('ST_Intention', 'ST_Stellung_OP'))"/>

			<xsl:variable name="menge_bestrahlung">
				<xsl:copy-of select="aqua:fields($ref_fields, ('ST_Zielgebiet', 'ST_Seite_Zielgebiet', 'ST_Beginn_Datum', 'ST_Ende_Datum', 'ST_Applikationsart'))"/>
			</xsl:variable>

			<xsl:variable name="menge_dosis">
				<xsl:apply-templates select="$cases//felder[1]" mode="stdosis"/>
			</xsl:variable>			
			
			<xsl:if test="$menge_bestrahlung/*">
				<Menge_Bestrahlung>
					<Bestrahlung>
						<xsl:copy-of select="$menge_bestrahlung"/>
						<xsl:if test="$menge_dosis/*">
							<xsl:copy-of select="$menge_dosis"/>
						</xsl:if>
					</Bestrahlung>
				</Menge_Bestrahlung>
			</xsl:if>

			<xsl:copy-of select="aqua:fields($ref_fields, ('ST_Ende_Grund'))"/>
			<xsl:variable name="residualstatus">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Lokale_Beurteilung_Residualstatus', 'Gesamtbeurteilung_Residualstatus'))"/>
			</xsl:variable>
			<xsl:if test="$residualstatus/*">
				<Residualstatus>
					<xsl:copy-of select="$residualstatus"/>
				</Residualstatus>
			</xsl:if>

			<xsl:variable name="menge_nebenwirkung">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Nebenwirkung_Grad', 'Nebenwirkung_Art', 'Nebenwirkung_Version'))"/>
			</xsl:variable>
			<xsl:if test="$menge_nebenwirkung/*">
				<Menge_Nebenwirkung>
					<ST_Nebenwirkung>
						<xsl:copy-of select="$menge_nebenwirkung"/>
					</ST_Nebenwirkung>
				</Menge_Nebenwirkung>
			</xsl:if>
			
			<!-- Modul_Allgemein -->
			<xsl:variable name="modul_allgemein_dienstkontakt">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumSozialdienstkontakt'))"/>
			</xsl:variable>
			
			<xsl:variable name="modul_allgemein_rekrutierung">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumStudienrekrutierung'))"/>
			</xsl:variable>
			<xsl:if test="$modul_allgemein_dienstkontakt/* or $modul_allgemein_rekrutierung/*">
				<Modul_Allgemein>
					<xsl:if test="$modul_allgemein_dienstkontakt/*">
						<xsl:copy-of select="$modul_allgemein_dienstkontakt"/>
					</xsl:if>	
					<xsl:if test="$modul_allgemein_rekrutierung/*">
						<xsl:copy-of select="$modul_allgemein_rekrutierung"/>
					</xsl:if>
				</Modul_Allgemein>
			</xsl:if>
			
			<xsl:copy-of select="aqua:fields($ref_fields, ('Anmerkung'))"/>
			
		</xsl:variable>
		<xsl:if test="$st/*">
			<ST ST_ID="{$ref_fields/ST_ID/@V}">
				<xsl:copy-of select="$st"/>
			</ST>
		</xsl:if>
	</xsl:template>


	<xsl:template name="syst">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<xsl:variable name="syst">
			<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Intention', 'SYST_Stellung_OP'))"/>

			<xsl:variable name="menge_therapieart">
				<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Therapieart'))"/>
			</xsl:variable>
			<xsl:if test="$menge_therapieart/*">
				<Menge_Therapieart>
					<xsl:copy-of select="$menge_therapieart"/>
				</Menge_Therapieart>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Therapieart_Anmerkung', 'SYST_Protokoll', 'SYST_Beginn_Datum'))"/>
			<xsl:variable name="menge_substanz">
				<xsl:copy-of select="aqua:fields($ref_fields/*, ('SYST_Substanz'))"/>
			</xsl:variable>
			<xsl:if test="$menge_substanz/*">
				<Menge_Substanz>
					<xsl:copy-of select="$menge_substanz"/>
				</Menge_Substanz>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Ende_Grund', 'SYST_Ende_Datum'))"/>
			<xsl:variable name="residualstatus">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Lokale_Beurteilung_Residualstatus', 'Gesamtbeurteilung_Residualstatus'))"/>
			</xsl:variable>
			<xsl:if test="$residualstatus/*">
				<Residualstatus>
					<xsl:copy-of select="$residualstatus"/>
				</Residualstatus>
			</xsl:if>

			<xsl:variable name="menge_nebenwirkung">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Nebenwirkung_Grad', 'Nebenwirkung_Art', 'Nebenwirkung_Version'))"/>
			</xsl:variable>
			<xsl:if test="$menge_nebenwirkung/*">
				<Menge_Nebenwirkung>
					<SYST_Nebenwirkung>
						<xsl:copy-of select="$menge_nebenwirkung"/>
					</SYST_Nebenwirkung>
				</Menge_Nebenwirkung>
			</xsl:if>
			<!-- Modul_Allgemein -->
			<xsl:variable name="modul_allgemein_dienstkontakt">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumSozialdienstkontakt'))"/>
			</xsl:variable>
			
			<xsl:variable name="modul_allgemein_rekrutierung">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumStudienrekrutierung'))"/>
			</xsl:variable>
			<xsl:if test="$modul_allgemein_dienstkontakt/* or $modul_allgemein_rekrutierung/*">
				<Modul_Allgemein>
					<xsl:if test="$modul_allgemein_dienstkontakt/*">
							<xsl:copy-of select="$modul_allgemein_dienstkontakt"/>
					</xsl:if>	
					<xsl:if test="$modul_allgemein_rekrutierung/*">
							<xsl:copy-of select="$modul_allgemein_rekrutierung"/>
					</xsl:if>
				</Modul_Allgemein>
			</xsl:if>
			
			<xsl:copy-of select="aqua:fields($ref_fields, ('Anmerkung'))"/>
			
		</xsl:variable>
		
		<xsl:if test="$syst/*">
			<SYST SYST_ID="{$ref_fields/SYST_ID/@V}">
				<xsl:copy-of select="$syst"/>
			</SYST>
		</xsl:if>
	</xsl:template>


	<xsl:template name="verlauf">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<xsl:variable name="verlauf">
			<xsl:apply-templates select="$cases[1]//felder" mode="histologie"/>

			<xsl:variable name="menge_tnm">
				<xsl:apply-templates select="$cases//felder[1]" mode="tnm"/>
			</xsl:variable>
			<xsl:if test="$menge_tnm/*">
					<xsl:copy-of select="$menge_tnm"/>
			</xsl:if>

			<xsl:variable name="menge_wk">
				<xsl:apply-templates select="$cases//felder[1]" mode="wk"/>
			</xsl:variable>
			<xsl:if test="$menge_wk/*">
				<Menge_Weitere_Klassifikation>
					<xsl:copy-of select="$menge_wk"/>
				</Menge_Weitere_Klassifikation>
			</xsl:if>
			
			<xsl:copy-of select="aqua:fields($ref_fields, ('Untersuchungsdatum_Verlauf', 'Gesamtbeurteilung_Tumorstatus', 'Verlauf_Lokaler_Tumorstatus', 'Verlauf_Tumorstatus_Lymphknoten', 'Verlauf_Tumorstatus_Fernmetastasen'))"/>

			<xsl:variable name="menge_fm">
				<xsl:apply-templates select="$cases//felder[1]" mode="fm"/>
			</xsl:variable>
			<xsl:if test="$menge_fm/*">
				<Menge_FM>
					<xsl:copy-of select="$menge_fm"/>
				</Menge_FM>
			</xsl:if>
			
			<xsl:copy-of select="aqua:fields($ref_fields, ('Allgemeiner_Leistungszustand'))"/>
			
			<!-- Modul_Allgemein -->
			<xsl:variable name="modul_allgemein_dienstkontakt">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumSozialdienstkontakt'))"/>
			</xsl:variable>
			
			<xsl:variable name="modul_allgemein_rekrutierung">
				<xsl:copy-of select="aqua:fields($ref_fields, 
					('DatumStudienrekrutierung'))"/>
			</xsl:variable>
			<xsl:if test="$modul_allgemein_dienstkontakt/* or $modul_allgemein_rekrutierung/*">
				<Modul_Allgemein>
					<xsl:if test="$modul_allgemein_dienstkontakt/*">
						<xsl:copy-of select="$modul_allgemein_dienstkontakt"/>
					</xsl:if>	
					<xsl:if test="$modul_allgemein_rekrutierung/*">
						<xsl:copy-of select="$modul_allgemein_rekrutierung"/>
					</xsl:if>
				</Modul_Allgemein>
			</xsl:if>
			<!-- Ende Modul -->
			
			<xsl:variable name="tod">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Sterbedatum', 'Tod_tumorbedingt'))"/>

				<xsl:variable name="menge_todesursache">
					<xsl:copy-of select="aqua:fields($ref_fields, ('Todesursache_ICD','Todesursache_ICD_Version'))"/>
				</xsl:variable>
				<xsl:if test="$menge_todesursache/*">
					<Menge_Todesursache>
						<xsl:copy-of select="$menge_todesursache"/>
					</Menge_Todesursache>
				</xsl:if>
			</xsl:variable>
			<xsl:if test="$tod/*">
				<Tod>
					<xsl:copy-of select="$tod"/>
				</Tod>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Anmerkung'))"/>
		</xsl:variable>
		
		<xsl:if test="$verlauf/*">
			<Verlauf Verlauf_ID="{$ref_fields/Verlauf_ID/@V}">
				<xsl:copy-of select="$verlauf"/>
			</Verlauf>
		</xsl:if>
	</xsl:template>


	<xsl:template name="tumorkonferenz">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<xsl:variable name="tumorkonferenz">
			<xsl:copy-of select="aqua:fields($ref_fields, ('Tumorkonferenz_Datum', 'Tumorkonferenz_Typ'))"/>
		</xsl:variable>
		<xsl:if test="$tumorkonferenz/*">
			<Tumorkonferenz Tumorkonferenz_ID="{$ref_fields/Tumorkonferenz_ID/@V}">
				<xsl:copy-of select="$tumorkonferenz"/>
			</Tumorkonferenz>
		</xsl:if>
	</xsl:template>


	<xsl:template name="zusatzitem">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases[1]//felder"/>
		<Zusatzitem>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Datum', 'Art', 'Wert', 'Bemerkung'))"/>
		</Zusatzitem>
	</xsl:template>


	<xsl:template match="felder" mode="histologie">
		<xsl:variable name="hist">
			<xsl:copy-of select="aqua:fields(., ('Tumor_Histologiedatum','Histologie_EinsendeNr', 'Morphologie_Code', 'Morphologie_ICD_O_Version', 'Morphologie_Freitext_XXX_KRD_MORPHTEXT','Morphologie_Freitext_XXX_KRO_MORPHTEXT','Morphologie_Freitext_XXX_KRV_MORPHTEXT'))"/>

			<xsl:choose>
				<xsl:when test="Grading[@V = '4']">
					<Grading>4</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = 'H']">
					<Grading>H</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = '3']">
					<Grading>3</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = 'M']">
					<Grading>M</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = '2']">
					<Grading>2</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = 'L']">
					<Grading>L</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = '1']">
					<Grading>1</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = '0']">
					<Grading>0</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = 'B']">
					<Grading>B</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = 'U']">
					<Grading>U</Grading>
				</xsl:when>
				<xsl:when test="Grading[@V = 'T']">
					<Grading>T</Grading>
				</xsl:when>
			</xsl:choose>

			<xsl:copy-of select="aqua:fields(., ('LK_untersucht', 'LK_befallen', 'Sentinel_LK_untersucht', 'Sentinel_LK_befallen'))"/>
		</xsl:variable>
		<xsl:if test="$hist/*">
			<Histologie Histologie_ID="{Histologie_ID/@V}">
				<xsl:copy-of select="$hist"/>
			</Histologie>
		</xsl:if>
	</xsl:template>


	<xsl:template match="felder" mode="tk">
		<Tumorkonferenz>
			<xsl:copy-of select="aqua:fields(., ('Tumorkonferenz_Datum', 'Tumorkonferenz_Typ'))"/>
		</Tumorkonferenz>
	</xsl:template>


	<xsl:template match="felder" mode="fm">
		<xsl:variable name="date" select="FM_Diagnosedatum[1]/@V"/>
		<xsl:if test="$date != ''">
		<xsl:for-each select="FM_Lokalisation[@V != ''] ">
			<Fernmetastase>
				<FM_Diagnosedatum><xsl:value-of select="$date"/></FM_Diagnosedatum>
				<FM_Lokalisation><xsl:value-of select="./@V"/></FM_Lokalisation>
			</Fernmetastase>
		</xsl:for-each>
		<!--<Fernmetastase>
			<xsl:copy-of select="aqua:fields(., ('FM_Diagnosedatum', 'FM_Lokalisation'))"/>
		</Fernmetastase>-->
		</xsl:if>
	</xsl:template>


	<xsl:template match="felder/Menge_Weitere_Klassifikation/Weitere_Klassifikation" mode="wk">
		<xsl:variable name="wkl">
			<xsl:copy-of select="aqua:fields(., ('Datum_XXX_KRD_WK','Datum_XXX_KRV_WK', 'Name', 'Stadium'))"/>
		</xsl:variable>
	<xsl:if test="$wkl/*">
			<Weitere_Klassifikation>
				<xsl:copy-of select="$wkl"/>
			</Weitere_Klassifikation>
		</xsl:if>		
	</xsl:template>


	<xsl:template match="felder" mode="tnm">
		<xsl:variable name="tnm">
			<xsl:copy-of select="aqua:fields(., ('TNM_Datum', 'TNM_Version', 'TNM_y_Symbol', 'TNM_r_Symbol', 'TNM_a_Symbol', 'TNM_c_p_u_Praefix_T', 'TNM_T', 'TNM_m_Symbol', 'TNM_c_p_u_Praefix_N', 'TNM_N', 'TNM_c_p_u_Praefix_M', 'TNM_M', 'TNM_L', 'TNM_V', 'TNM_Pn', 'TNM_S'))"/>
		</xsl:variable>
		<xsl:if test="$tnm/*">
			<TNM TNM_ID="{TNM_ID/@V}">
				<xsl:copy-of select="$tnm"/>
			</TNM>
		</xsl:if>
	</xsl:template>
	
<!-- TNM Diagnose -->
		<xsl:template match="TNM" mode="tnmd">
		<xsl:variable name="tnmd" >
			<xsl:copy-of select="aqua:fields(., ('TNM_Datum', 'TNM_Version', 'TNM_y_Symbol', 'TNM_r_Symbol', 'TNM_a_Symbol', 'TNM_c_p_u_Praefix_T', 'TNM_T', 'TNM_m_Symbol', 'TNM_c_p_u_Praefix_N', 'TNM_N', 'TNM_c_p_u_Praefix_M', 'TNM_M'))"/>
		</xsl:variable>
		
		<xsl:if test="$tnmd/*">
				<xsl:copy-of select="$tnmd"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="felder" mode="tnme">
		<xsl:variable name="tnme">
			<xsl:copy-of select="aqua:fields(., ('TNM_L', 'TNM_V', 'TNM_Pn', 'TNM_S'))"/>
		</xsl:variable>
		<xsl:if test="$tnme/*">
			<xsl:copy-of select="$tnme"/>
		</xsl:if>
	</xsl:template>
	
<!-- Ende tnm Diagnose -->
	<xsl:template match="felder" mode="stdosis">
		<xsl:variable name="lEinzeldosis">
			<xsl:copy-of select="aqua:fields(., ('ST_Einzeldosis','ST_Einzeldosis_Einheit'))"/>
		</xsl:variable>
		<xsl:variable name="lGesamtdosis">
			<xsl:copy-of select="aqua:fields(., ('ST_Gesamtdosis','ST_Gesamtdosis_Einheit'))"/>
		</xsl:variable>
		
		<xsl:if test="$lGesamtdosis/*">
			<ST_Gesamtdosis>
				<xsl:copy-of select="$lGesamtdosis"/>
			</ST_Gesamtdosis>
		</xsl:if>
		
		<xsl:if test="$lEinzeldosis/*">
			<ST_Einzeldosis>
				<xsl:copy-of select="$lEinzeldosis"/>
			</ST_Einzeldosis>
		</xsl:if>		
	</xsl:template>

	<xsl:template match="felder/Menge_Fruehere_Tumorerkrankung/Fruehere_Tumorerkrankung" mode="fruehtumor">
		<xsl:variable name="fruehtumor">
			<xsl:copy-of select="aqua:fields(., ('Freitext_XXX_KRD_TUMORFRUEH', 'ICD_Code_XXX_KRD_FRUEHDIAG', 'ICD_Version_XXX_KRD_FRUEHDIAG','Diagnosedatum_XXX_KRD_FRUEHDIAG'))"/>
		</xsl:variable>
		<xsl:if test="$fruehtumor/*">
			<Fruehere_Tumorerkrankung>
				<xsl:copy-of select="$fruehtumor"/>
			</Fruehere_Tumorerkrankung>
		</xsl:if>		
	</xsl:template>
	

	<xsl:template match="felder" mode="melder">
		<Melder Melder_ID="{Melder_ID/@V}">
			<xsl:copy-of select="aqua:fields(., ('Melder_IKNR', 'Melder_LANR', 'Melder_BSNR', 'Meldende_Stelle', 'Melder_KH_Abt_Station_Praxis', 'Melder_Arztname', 'Melder_Anschrift', 'Melder_PLZ', 'Melder_Ort', 'Melder_Bankname', 'Melder_Kontoinhaber', 'Melder_BIC', 'Melder_IBAN'))"/>
		</Melder>
	</xsl:template>


	<xsl:template match="case" mode="patient_stammdaten">
		<xsl:variable name="base" select="(./qs_data/*/felder)[1]"/>
		<xsl:copy-of select="aqua:fields($base, ('KrankenversichertenNr', 'KrankenkassenNr', 'Patienten_Nachname', 'Patienten_Titel', 'Patienten_Namenszusatz', 'Patienten_Vornamen', 'Patienten_Geburtsname'))"/>
		
		
		<xsl:variable name="fruername">
			<xsl:copy-of select="aqua:fields($base, ('Patienten_Frueherer_Name'))"/>
		</xsl:variable>
		<xsl:if test="$fruername/*">
			<Menge_Frueherer_Name>
				<xsl:copy-of select="$fruername"/>
			</Menge_Frueherer_Name>
		</xsl:if>	
		
		<xsl:copy-of select="aqua:fields($base, ('Patienten_Geschlecht', 'Patienten_Geburtsdatum'))"/>
		<Menge_Adresse>
			<Adresse>
				<xsl:copy-of select="aqua:fields($base, ('Patienten_Strasse', 'Patienten_Hausnummer', 'Patienten_Land', 'Patienten_PLZ', 'Patienten_Ort'))"/>
			</Adresse>
		</Menge_Adresse>
	</xsl:template>


	<xsl:template match="felder" mode="absender">
		<Absender Absender_ID="{Absender_ID/@V}" Software_ID="{Software_ID/@V}" Installations_ID="{Installations_ID/@V}">
			<xsl:copy-of select="aqua:fields(., ('Absender_Bezeichnung', 'Absender_Ansprechpartner', 'Absender_Anschrift', 'Absender_Telefon', 'Absender_EMail'))"/>
		</Absender>
	</xsl:template>


	<xsl:template match="node()" mode="value">
		<xsl:variable name="name" select="local-name(.)"/>
		<xsl:variable name="value" select="@V"/>
		<xsl:if test="$value != ''">
			<xsl:choose>
				<xsl:when test="$value = '9' and ($name = 'TNM_y_Symbol' or $name = 'TNM_r_Symbol' or $name = 'TNM_a_Symbol')">	
					<!-- leers Element <xsl:element name="{$name}"/>-->
				</xsl:when>
				<!-- umbennen und spliten von Variablen -->
				
				<xsl:when test="$name = 'ST_Einzeldosis' or $name = 'ST_Gesamtdosis'">
					<xsl:element name="Dosis">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:when>

				<xsl:when test="$name = 'ST_Einzeldosis_Einheit' or $name='ST_Gesamtdosis_Einheit'">
					<xsl:element name="Einheit">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:when>				
			
				<xsl:when test="$name = 'DatumStudienrekrutierung' or $name = 'DatumSozialdienstkontakt'">	
					<xsl:element name="{$name}">
					
						<xsl:choose>
							<xsl:when test="$value='U' or $value='N'">
									<xsl:element name="NU">
										<xsl:value-of select="$value"/>
									</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:element name="Datum">
									<xsl:value-of select="aqua:endate($value)"/>
								</xsl:element>	
							</xsl:otherwise>
						</xsl:choose>
					
					</xsl:element>	
					
					
				</xsl:when>
				
				<xsl:when test="$name = 'IntraopPraeparatkontroll'">
					<xsl:element name="IntraopPraeparatkontrolle">
							<xsl:value-of select="$value"/>
						</xsl:element>
				</xsl:when>
				
				<!-- extraieren von XXX Feldern -->
				<xsl:when test="contains($name,'_XXX_')">
					<xsl:element name="{substring-before($name,'_XXX_')}">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:when>

				<xsl:otherwise>
					<xsl:element name="{$name}"><xsl:value-of select="$value"/></xsl:element>
				</xsl:otherwise>
			</xsl:choose>
			<!--<xsl:element name="{local-name(.)}"><xsl:value-of select="@V"/></xsl:element>-->
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template name="dosis">
		<xsl:param name="value"/>
		<xsl:param name="name"/>
		<xsl:analyze-string select="$value" regex="(\d+)(GBq|Gy)">
			<xsl:matching-substring>
				<xsl:element name="{$name}">
					<xsl:element name="Dosis"> <xsl:value-of select="regex-group(1)" /></xsl:element>
					<xsl:element name="Einheit"> <xsl:value-of select="regex-group(2)" /></xsl:element>
				</xsl:element>	
			</xsl:matching-substring>
		</xsl:analyze-string>
	</xsl:template>

	<xsl:function name="aqua:fields">
		<xsl:param name="fields"/>
		<xsl:param name="field_names"/>
		<xsl:for-each select="$field_names">
			<xsl:variable name="field_name" select="."/>
			<xsl:apply-templates mode="value" select="$fields/*[local-name() = $field_name]"/>
		</xsl:for-each>
	</xsl:function>
	
	
	<xsl:function name="aqua:endate" as="xs:string*">
		<xsl:param name="dedate" as="xs:string"/>
		<xsl:analyze-string select="$dedate" regex="(\d{{2}})\.(\d{{2}})\.(\d{{4}})">
			<xsl:matching-substring>
				<xsl:value-of select="concat(regex-group(3),'-',regex-group(2),'-',regex-group(1))"/>
			</xsl:matching-substring>
		</xsl:analyze-string>
	</xsl:function>
	
</xsl:stylesheet>
